@@ -1,5 +1,5 @@
 regs.mean.sm <-
-function(y, mc=NULL, ar=NULL, mx=NULL)
+function(y, mc=NULL, ar=NULL, ewma=NULL, mx=NULL)
 {
 y.n <- length(y)
 mX <- NULL
@@ -17,6 +17,12 @@ if(!is.null(ar)){
 }
 mX <- cbind(mX, arlags)
 
+#EqWMA term:
+if(is.null(ewma)){EqWMA <- NULL}else{
+  EqWMA <- do.call(eqwma, c(list(y),ewma) )
+}
+mX <- cbind(mX, EqWMA)
+
 #create matrix of mean regressors mx:
 if(!is.null(mx)){
   mxnames <- colnames(mx)
@@ -38,5 +44,4 @@ out <- mX
 
 return(out)
 
-} #end regs.mean.sm
-
+}
